// Made by Willy, licensed under the Creative Commons - GNU 
// GPL license. 
// Rostock

use <bracket_MA.scad>

h = 28; // Total height.
tilt = 0.5; // Tilt bearings upward (the timing belt is pulling pretty hard).

module bearing_mount() {
  translate([0, 0, 2.8]) cylinder(r1=12, r2=9, h=1.1, center=true);
  translate([0, 0, -3.1]) cylinder(r1=9, r2=12, h=1.1, center=true);
}

x = 17.7; // Micro switch center.
y = 16; // Micro switch center.

module idler_end() {
  translate([0, 0, -h/2]) 
  difference() {
    union() {
      bracket(h);
      // Schrägen wie unten:
      rotate([0, 180, 0]) {
       for (x = [-30, 30]) {
        // Diagonal fins.
        translate([x, 29.5, 3.0]) intersection() {
          cube([7, 30, h+6], center=true);
          rotate([55, 0, 0]) translate([0, -50, 0])
            cube([20, 100, 100], center=true);
        }
        // Extra mounting screw holes.
        translate([x, 47, 4-h/2]) difference() {
         cylinder(r=6, h=8, center=true, $fn=24);
         translate([0, 1, 0]) cylinder(r=1.9, h=9, center=true, $fn=12);
        }
       }
      }
      translate([0, 7.5, 0]) rotate([90 - tilt, 0, 0]) bearing_mount();
      // Micro switch placeholder.
//      % translate([x, y, -h/2+2.75]) rotate([0, 0, 15])
//          cube([12.8, 5.8, 6.5], center=true);
      difference() {
        translate([20, 11.88, -h/2+5+9])
          cube([18+4, 8, 28], center=true); 
        translate([x, y, -h/2+4+9.5]) rotate([0, 0, 15])
          cube([30, 5.8, 30], center=true); // kl. Micros.
        translate([30, 12, -h/2+5+9])
          cylinder(r=3, h=30, center=true);
      }
      difference() {
        translate([-20, 11.88, -h/2+5+9])
          cube([18+4, 8, 28], center=true); 
        translate([-x, y, -h/2+4+9.5]) rotate([0, 0, -15])
          cube([30, 5.8, 30], center=true); // kl. Micros.
        translate([-30, 12, -h/2+5+9])
          cylinder(r=3, h=30, center=true);
      }
      // Neue Microschalter-Position:
      difference() {
       translate([34.5, 14, -6.5]) cube([5, 13.0, 15], center=true);
       translate([38.5, 14, -4]) rotate([0, -25, 0])
        cube([5, 14.0, 15], center=true);
      }
    }
    // Neue Microschalter-Position:
    translate([35, -11.75+22.5, -14+4.5]) rotate([0, 90, 0])
      rotate([0, 0, 30]) cylinder(r=1.0, h=10, center=true, $fn=6); 
    translate([35, -11.75+22.5+6.6, -14+4.5]) rotate([0, 90, 0])
      rotate([0, 0, 30]) cylinder(r=1.0, h=10, center=true, $fn=6); 
    // war schon:
//    translate([x, y, -h/2+4.5]) rotate([0, 0, 15]) {
//      translate([-6.5/2, 0, 0]) rotate([90, 0, 0])
//        cylinder(r=1.1, h=26, center=true, $fn=12); // Loch Micro-Schalter
//      translate([6.5/2, 0, 0]) rotate([90, 0, 0])
//        cylinder(r=1.1, h=26, center=true, $fn=12);
//    }
    translate([0, 8, 0]) rotate([90 - tilt, 0, 0])
      rotate([180, 0, 0]) loch60(40, 2.5);  // MA

    for (z = [-7, 7])
      translate([0, -1, z]) screws();
  }
}

module loch60(ll, rr) { // Reprap-Loch mit 60°
 cylinder(h = ll, r = rr, $fn=40, center = true);
 difference() { 
  translate(v = [0, rr, 0]) { // 60° Wände
   rotate(a=90, v=[0,0,1]) {
    cylinder(h = ll, r = rr, $fn=3, center = true);
   }
  }
  rotate(a= 0, v=[0,0,1]) { // Welle - 60° Deckel
   translate(v = [0, 1.5*rr, 0]) { 
     cube([1.5*rr, rr, ll], center = true);
   }
  }
 }
}

rotate([180, 0, 0]) idler_end();


